==> jc-1.4.0.tar.gz: javax/imageio/stream/MemoryCacheImageOutputStream.h <==
// public class javax.imageio.stream.MemoryCacheImageOutputStream

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl
// @dep_class a6cc78290aff4a42 javax_imageio_stream_ImageOutputStreamImpl
// @dep_class 91e2b9bfafa8b64d javax_imageio_stream_MemoryCacheImageOutputStream

// header file dependencies
// @dep_header javax_imageio_stream_ImageOutputStreamImpl

#include "javax/imageio/stream/ImageOutputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_MemoryCacheImageOutputStream_H_
#define _JC_javax_imageio_stream_MemoryCacheImageOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_refs	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_nonrefs	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$refs	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$refs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$nonrefs	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$object;

typedef const struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vmethods	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtable	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtable;
typedef const struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$flushBefore$bf21d8a7b8a41c3e(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, jlong);
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$isCached$7eabc2d936c77133(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$isCachedFile$ed19c4c24a1815db(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$isCachedMemory$53b63747781a10df(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
extern jint _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
extern jint _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, jint);
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$flushBefore$bf21d8a7b8a41c3e;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$isCached$7eabc2d936c77133;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$isCachedFile$ed19c4c24a1815db;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$isCachedMemory$53b63747781a10df;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
	void	(*flushBefore$bf21d8a7b8a41c3e)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, jlong);
	jboolean	(*isCached$7eabc2d936c77133)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
	jboolean	(*isCachedFile$ed19c4c24a1815db)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
	jboolean	(*isCachedMemory$53b63747781a10df)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_ImageOutputStreamImpl$vmethods	javax_imageio_stream_ImageOutputStreamImpl;
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vmethods	javax_imageio_stream_MemoryCacheImageOutputStream;
};

// Vtype
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_refs {
	struct _jc_java_io_OutputStream$object	*stream;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$refs {
    _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_refs	javax_imageio_stream_MemoryCacheImageOutputStream;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_refs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_nonrefs	javax_imageio_stream_MemoryCacheImageOutputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object {
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype	*vtype;
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype _jc_javax_imageio_stream_MemoryCacheImageOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_MemoryCacheImageOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_MemoryCacheImageOutputStream$class_object;

#endif	/* _JC_javax_imageio_stream_MemoryCacheImageOutputStream_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/stream/MemoryCacheImageOutputStream.h <==
// public class javax.imageio.stream.MemoryCacheImageOutputStream

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl
// @dep_class a6cc78290aff4a42 javax_imageio_stream_ImageOutputStreamImpl
// @dep_class 91e2b9bfafa8b64d javax_imageio_stream_MemoryCacheImageOutputStream

// header file dependencies
// @dep_header javax_imageio_stream_ImageOutputStreamImpl

#include "javax/imageio/stream/ImageOutputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_MemoryCacheImageOutputStream_H_
#define _JC_javax_imageio_stream_MemoryCacheImageOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_refs	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_nonrefs	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$refs	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$refs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$nonrefs	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$object;

typedef const struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vmethods	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtable	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtable;
typedef const struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$flushBefore$bf21d8a7b8a41c3e(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, jlong) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$isCached$7eabc2d936c77133(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$isCachedFile$ed19c4c24a1815db(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$isCachedMemory$53b63747781a10df(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$flushBefore$bf21d8a7b8a41c3e;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$isCached$7eabc2d936c77133;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$isCachedFile$ed19c4c24a1815db;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$isCachedMemory$53b63747781a10df;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_javax_imageio_stream_MemoryCacheImageOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	void	(*flushBefore$bf21d8a7b8a41c3e)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, jlong) _JC_JCNI_ATTR;
	jboolean	(*isCached$7eabc2d936c77133)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCachedFile$ed19c4c24a1815db)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCachedMemory$53b63747781a10df)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_ImageOutputStreamImpl$vmethods	javax_imageio_stream_ImageOutputStreamImpl;
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vmethods	javax_imageio_stream_MemoryCacheImageOutputStream;
};

// Vtype
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_refs {
	struct _jc_java_io_OutputStream$object	*stream;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$refs {
    _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_refs	javax_imageio_stream_MemoryCacheImageOutputStream;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_refs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_ImageOutputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageOutputStreamImpl;
    _jc_javax_imageio_stream_MemoryCacheImageOutputStream$sub_nonrefs	javax_imageio_stream_MemoryCacheImageOutputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_MemoryCacheImageOutputStream$object {
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype	*vtype;
	_jc_javax_imageio_stream_MemoryCacheImageOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_MemoryCacheImageOutputStream$vtype _jc_javax_imageio_stream_MemoryCacheImageOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_MemoryCacheImageOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_MemoryCacheImageOutputStream$class_object;

#endif	/* _JC_javax_imageio_stream_MemoryCacheImageOutputStream_H_ */
